==> wiki3_4_4.zip: wiki3_4_4/plugin/farm/CreateWikiHandler.pm <==
#############################################################################
#
# Wikiޤ
#
#############################################################################
package plugin::farm::CreateWikiHandler;
#use strict;
use plugin::farm::WikiList;
#===========================================================================
# 󥹥ȥ饯
#===========================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================================
# ϥɥ
#===========================================================================
sub do_action{
	my $self  = shift;
	my $farm  = shift;
	my $cgi   = $farm->get_CGI;
	my $child = $cgi->param("child");
	my $admin_id   = $cgi->param("admin_id");
	my $admin_pass = $cgi->param("admin_pass");
	
	my $can_create = 1;
	
	my $config = &Util::load_config_hash($farm,$farm->config('farmconf_file'));
	my $login  = $farm->get_login_info();
	if($config->{create}==1){
		if(!defined($login)){
			$can_create = 0;
			#return $farm->error("WikiκϵĤƤޤ");
		}
	} elsif($config->{create}==2){
		if(!defined($login) || $login->{type}!=0){
			$can_create = 0;
			#return $farm->error("WikiκϵĤƤޤ");
		}
	}
	
	if($child eq ""){
		# Wiki̾ϥե
		$farm->set_title("WikiFarm",1);
		my $buf = "";
		
		if($can_create==1){
			$buf = "<h2>Wikiκ</h2>\n".
			       "<form method=\"post\" action=\"".$farm->config('script_name')."\">\n".
			       "  <h3>Wiki̾</h3>\n".
			       "  <p>ꤷWiki̾URL˴ޤޤޤΤǤWikiħɽ".
			       "     Ǥû̾Ĥ뤳Ȥ򥪥ᤷޤ".
			       "     ȾѱѿѤǤޤ</p>\n".
			       "  <p>Wiki̾<input type=\"text\" name=\"child\" size=\"40\"></p>".
			       "  <h3>Ԥξ</h3>\n".
			       "  <p>WikiδIDȥѥɤꤷƤ".
			       "     ȾѱѿѤǤޤ</p>\n".
			       "  <p>ID<input type=\"text\" size=\"20\" name=\"admin_id\">\n".
			       "     Pass<input type=\"password\" size=\"20\" name=\"admin_pass\">\n".
			       "  </p>\n".
			       "  <input type=\"submit\" value=\"  \">".
			       "  <input type=\"hidden\" name=\"action\" value=\"CREATE_WIKI\">".
			       "</form>\n";
		}
		
		# Wikiΰ
		my $wikilist = plugin::farm::WikiList->new();
		my $listcnt  = $wikilist->inline($farm);
		$buf .= "<h2>WikiȤΰ</h2>\n";
		if($listcnt eq "<ul>\n</ul>\n"){
			$buf .= "<p>ߤWiki۲ˤWikiȤϤޤ</p>";
		} else {
			$buf .= "<p>ߤWiki۲ˤϰʲWikiȤ¸ߤޤ</p>".$listcnt;
		}
		
		return $buf;
		
	}else{
		if($can_create==0){
			return $farm->error("WikiκϵĤƤޤ");
		}
		
		# ϥå
		if(!($child =~ /^[A-Za-z0-9]+$/)){
			return $farm->error(&Util::escapeHTML($child)."̾ΤǤ");
		
		} elsif($admin_id eq ""){
			return $farm->error("IDϤƤ");
			
		} elsif($admin_pass eq ""){
			return $farm->error("ԥѥɤϤƤ");
			
		} elsif(!($admin_id =~ /^[A-Za-z0-9]+$/)){
			return $farm->error("IDǤ");
		
		} elsif(!($admin_pass =~ /^[A-Za-z0-9]+$/)){
			return $farm->error("ԥѥɤǤ");
		
		# Wikiνʣå
		} elsif($farm->wiki_exists($child)){
			return $farm->error(&Util::escapeHTML($child)."ϴ¸ߤޤ");
		
		# 桼νʣå
		#} elsif($farm->user_exists($admin_id)){
		#	return $farm->error("ID".&Util::escapeHTML($admin_id)."Υ桼ϴ¸ߤޤ");
			
		# Wiki
		} else {
			$farm->create_wiki($child,$admin_id,$admin_pass);
			$farm->set_title(&Util::escapeHTML($child)."ޤ");
			return "<a href=\"".$farm->config('script_name')."/".&Util::escapeHTML($child)."\">".
			       &Util::escapeHTML($child)."</a>ޤ";
		}
	}
}

1;

==> wiki3_5_0.zip: wiki3_5_0/plugin/farm/CreateWikiHandler.pm <==
#############################################################################
#
# Wikiޤ
#
#############################################################################
package plugin::farm::CreateWikiHandler;
#use strict;
use plugin::farm::WikiList;
#===========================================================================
# 󥹥ȥ饯
#===========================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================================
# ϥɥ
#===========================================================================
sub do_action{
	my $self  = shift;
	my $farm  = shift;
	my $cgi   = $farm->get_CGI;
	my $child = $cgi->param("child");
	my $admin_id   = $cgi->param("admin_id");
	my $admin_pass = $cgi->param("admin_pass");
	
	my $can_create = 1;
	
	my $config = &Util::load_config_hash($farm,$farm->config('farmconf_file'));
	my $login  = $farm->get_login_info();
	if($config->{create}==1){
		if(!defined($login)){
			$can_create = 0;
			#return $farm->error("WikiκϵĤƤޤ");
		}
	} elsif($config->{create}==2){
		if(!defined($login) || $login->{type}!=0){
			$can_create = 0;
			#return $farm->error("WikiκϵĤƤޤ");
		}
	}
	
	if($child eq ""){
		# Wiki̾ϥե
		$farm->set_title("WikiFarm",1);
		my $buf = "";
		
		if($can_create==1){
			$buf = "<h2>Wikiκ</h2>\n".
			       "<form method=\"post\" action=\"".$farm->config('script_name')."\">\n".
			       "  <h3>Wiki̾</h3>\n".
			       "  <p>ꤷWiki̾URL˴ޤޤޤΤǤWikiħɽ".
			       "     Ǥû̾Ĥ뤳Ȥ򥪥ᤷޤ".
			       "     ȾѱѿѤǤޤ</p>\n".
			       "  <p>Wiki̾<input type=\"text\" name=\"child\" size=\"40\"></p>".
			       "  <h3>Ԥξ</h3>\n".
			       "  <p>WikiδIDȥѥɤꤷƤ".
			       "     ȾѱѿѤǤޤ</p>\n".
			       "  <p>ID<input type=\"text\" size=\"20\" name=\"admin_id\">\n".
			       "     Pass<input type=\"password\" size=\"20\" name=\"admin_pass\">\n".
			       "  </p>\n".
			       "  <input type=\"submit\" value=\"  \">".
			       "  <input type=\"hidden\" name=\"action\" value=\"CREATE_WIKI\">".
			       "</form>\n";
		}
		
		# Wikiΰ
		my $wikilist = plugin::farm::WikiList->new();
		my $listcnt  = $wikilist->paragraph($farm);
		
		$buf .= "<h2>WikiȤΰ</h2>\n";
		
		if($listcnt eq "<ul>\n</ul>\n"){
			$buf .= "<p>ߤWiki۲ˤWikiȤϤޤ</p>";
		} else {
			$buf .= "<p>ߤWiki۲ˤϰʲWikiȤ¸ߤޤ</p>".$listcnt;
		}
		
		return $buf;
		
	}else{
		if($can_create==0){
			return $farm->error("WikiκϵĤƤޤ");
		}
		
		# ϥå
		if(!($child =~ /^[A-Za-z0-9]+$/)){
			return $farm->error(&Util::escapeHTML($child)."̾ΤǤ");
		
		} elsif($admin_id eq ""){
			return $farm->error("IDϤƤ");
			
		} elsif($admin_pass eq ""){
			return $farm->error("ԥѥɤϤƤ");
			
		} elsif(!($admin_id =~ /^[A-Za-z0-9]+$/)){
			return $farm->error("IDǤ");
		
		} elsif(!($admin_pass =~ /^[A-Za-z0-9]+$/)){
			return $farm->error("ԥѥɤǤ");
		
		# Wikiνʣå
		} elsif($farm->wiki_exists($child)){
			return $farm->error(&Util::escapeHTML($child)."ϴ¸ߤޤ");
		
		# 桼νʣå
		#} elsif($farm->user_exists($admin_id)){
		#	return $farm->error("ID".&Util::escapeHTML($admin_id)."Υ桼ϴ¸ߤޤ");
			
		# Wiki
		} else {
			$farm->create_wiki($child,$admin_id,$admin_pass);
			$farm->set_title(&Util::escapeHTML($child)."ޤ");
			return "<a href=\"".$farm->config('script_name')."/".&Util::escapeHTML($child)."\">".
			       &Util::escapeHTML($child)."</a>ޤ";
		}
	}
}

1;
